@@ -112,7 +112,7 @@ _NOT_PASSED = object()
 class Password(Auth):
 
     #: Valid options for Password plugin
-    valid_options = [
+    valid_options = {
         'access_info',
         'auth_url',
         'username',
@@ -120,9 +120,11 @@ class Password(Auth):
         'password',
         'project_id',
         'project_name',
+        'tenant_name',
+        'tenant_id',
         'reauthenticate',
         'trust_id',
-    ]
+    }
 
     def __init__(self, auth_url, username=_NOT_PASSED, password=None,
                  user_id=_NOT_PASSED, **kwargs):
@@ -165,15 +167,17 @@ class Password(Auth):
 class Token(Auth):
 
     #: Valid options for this plugin
-    valid_options = [
+    valid_options = {
         'access_info',
         'auth_url',
         'project_id',
         'project_name',
+        'tenant_name',
+        'tenant_id',
         'reauthenticate',
         'token',
         'trust_id',
-    ]
+    }
 
     def __init__(self, auth_url, token, **kwargs):
         """A plugin for authenticating with an existing token.
